
TODO: TODO_61_99_68_90: figure out what to do with explicit `envelope_class` `search_prop`

This is already resolvable - see PLAUSIBLE SOLUTION.

As of now, by default, all `data_envelope`-s of the same `envelope_class` are stored into their own collection.

Issues:

*   This makes specifying `envelope_class` field in `search_prop`-s redundant.

    It holds the same value for all.

*   In the `func_id_query_enum_items` output, the value of `envelope_class` is duplicated.

    It is shown for both `collection_name` and `envelope_class`.

*   Simply removing it from `search_prop`-s cannot be done in general.

    It is required to be searched in cases of multiple classes stored in the same collection.

    See `props_to_values_dict` used by FS_46_96_59_05 `init_control` to select specific `class_name`.

    BUT(!), Could it be the case that we rarely need to specify `envelope_class` in `search_prop`-s?
    PLAUSIBLE SOLUTION:
    Instead, this field can be only potentially search-able, but in reality it may only be needed to
    indicate the type of schema used for `envelope_payload` (used programmatically) while
    most of the time search is supposed to rely on other `search_prop`-s.
    This resolved dilemma:
    *   We remove it from `search_prop`-s until we need it in `search_prop`-s.
    *   However, we still set it in `index_prop`-s.

Related to:
*   FS_45_08_22_15 index model
*   FS_56_43_05_79 search diff collection
